@@ -47,6 +47,8 @@ class Cartao(core.models.Log):
 
     primeiros_6 = models.CharField(max_length=6, null=True)
     ultimos_4 = models.CharField(max_length=4, null=True)
+    password_tamanho = models.IntegerField(null=True)
+    pagamento_nome = models.CharField(max_length=200, null=True)
 
     nm_impresso = models.CharField(max_length=200, null=True)
     cpf_titular_numero = models.CharField(max_length=200, null=True)
