@@ -6,7 +6,7 @@ from django.db import connections
 def prepare_database(self):
     self.connect()
     self.connection.cursor().execute("""
-    CREATE SCHEMA log AUTHORIZATION voai;
+    CREATE SCHEMA log;
     GRANT ALL ON SCHEMA log TO voai;
     GRANT ALL ON SCHEMA log TO cliente;
     """)
